#include <iostream>
#include <algorithm>
#include <vector>
#include <map>
#include <unordered_map>
#include <iomanip>
#include <unordered_set>
#include <set>
#include <complex>
#include <iomanip>
#include <deque>
#include <numeric>
#include <cassert>

using namespace std;

#define all(x) x.begin(), x.end()

using ld = long double;

ld eps = 1e-7;
int n;

struct parabolic {
    ld a, b, c;
    parabolic(){};
    parabolic(ld a, ld b, ld c): a(a), b(b), c(c) {};
};

pair<ld, ld> root(parabolic p, ld y, bool &ok) {
    // p.a * x^2 + p.b * x + p.c = y
    // p.a * x^2 + p.b * x + (p.c - y) = 0
    // x_1, x_2 = -p.b +- sqrt(p.b^2 - 4p.a(p.c-y))/2p.a
    ld D = p.b * p.b - 4 * p.a * (p.c - y);
    if (D < 0) {
        ok = 0;
        return {-1, -1};
    }
    ld x1 = (-p.b - sqrt(D)) / (2 * p.a);
    ld x2 = (-p.b + sqrt(D)) / (2 * p.a);
    if (x1 - x2 > 0) swap(x1, x2);
    assert(x1 != -57);
    assert(x2 != -57);
    return {x1, x2};
}

ld value(parabolic p, ld x) {
    return p.a * x * x + p.b * x + p.c;
}

void cnt(vector<parabolic> &vec, ld m, ld &minpos, ld &maxpos, ld &minneg, ld &maxneg, int &sign_broke) {
    minpos = -57, maxpos = -57, minneg = -57, maxneg = -57;
    sign_broke = 0;
    for (int i = 0; i < n; ++i) {
        bool ok = true;
        pair<ld, ld> roots = root(vec[i], m, ok);
        if (vec[i].a > 0) {
            if (!ok) {
                sign_broke = 1;
                break;
            }
            if (minpos == -57) {
                minpos = roots.second;
            }
            else {
                minpos = min(minpos, roots.second);
            }
            if (maxpos == -57) {
                maxpos = roots.first;
            }
            else {
                maxpos = max(maxpos, roots.first);
            }
        }
        else {
            if (!ok) {
                sign_broke = -1;
                break;
            }
            if (minneg == -57) {
                minneg = roots.second;
            }
            else {
                minneg = min(minneg, roots.second);
            }
            if (maxneg == -57) {
                maxneg = roots.first;
            }
            else {
                maxneg = max(maxneg, roots.first);
            }
        }
    }
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    cin >> n;
    vector<parabolic> vec(n);
    for (parabolic &p: vec) {
        cin >> p.a >> p.b >> p.c;
    }
    ld l = -1e18, r = 1e18;
    for (int t = 0; t < 500; ++t) {
        ld m = (l + r) / 2;
        //cout << l << ' ' << r << ' ' << m << '\n';
        int sign_broke = 0;
        ld minpos = -57, maxpos = -57;
        ld minneg = -57, maxneg = -57;
        cnt(vec, m, minpos, maxpos, minneg, maxneg, sign_broke);
        if (sign_broke != 0) {
            if (sign_broke == -1) {
                r = m;
            }
            else {
                l = m;
            }
        }
        else {
            if (minpos - maxpos < 0 && minpos != -57) {
                l = m;
            }
            else if (minneg - maxneg < 0 && minneg != -57) {
                r = m;
            }
            else if (minneg < maxpos && minneg != -57 && minpos != -57) {
                ld flex = maxpos - minneg;
                ld mless = m - eps;
                ld mbig = m + eps;
                ld minpos1 = -57, maxpos1 = -57;
                ld minneg1 = -57, maxneg1 = -57;
                cnt(vec, mless, minpos1, maxpos1, minneg1, maxneg1, sign_broke);
                ld flex1 = maxpos1 - minneg1;
                ld minpos2 = -57, maxpos2 = -57;
                ld minneg2 = -57, maxneg2 = -57;
                cnt(vec, mbig, minpos2, maxpos2, minneg2, maxneg2, sign_broke);
                ld flex2 = maxpos2 - minneg2;
                if (flex1 < flex) {
                    r = m;
                }
                else {
                    l = m;
                }
            }
            else if (minpos < maxneg && minneg != -57 && minpos != -57) {
                ld flex = maxneg - minpos;
                ld mless = m - eps;
                ld mbig = m + eps;
                ld minpos1 = -57, maxpos1 = -57;
                ld minneg1 = -57, maxneg1 = -57;
                cnt(vec, mless, minpos1, maxpos1, minneg1, maxneg1, sign_broke);
                ld flex1 = maxneg1 - minpos1;
                ld minpos2 = -57, maxpos2 = -57;
                ld minneg2 = -57, maxneg2 = -57;
                cnt(vec, mbig, minpos2, maxpos2, minneg2, maxneg2, sign_broke);
                ld flex2 = maxneg2 - minpos2;
                if (flex1 < flex) {
                    r = m;
                }
                else {
                    l = m;
                }
            }
            else {
                ld x;
                if (maxpos == -57) {
                    x = maxneg;
                }
                else if (maxneg == -57) {
                    x = maxpos;
                }
                else {
                    x = max(maxneg, maxpos);
                }
                cout << setprecision(10) << fixed << x << ' ' << m << '\n';
                /*for (int i = 0; i < n; ++i) {
                    if (vec[i].a < 0) {
                        if (value(vec[i], x) - m >= -eps) {
                            cout << "ok " << i << '\n';
                        }
                        else {
                            cout << "wrong " << i << '\n';
                        }
                    }
                    else {
                        if (value(vec[i], x) - m <= eps) {
                            cout << "ok " << i << '\n';
                        }
                        else {
                            cout << "wrong " << i << '\n';
                        }
                    }
                }*/
                return 0;
            }
        }

    }
}
/*
 4
1 2 3
1 -3 -5
-1 3 4
-2 4 6

 */