#include <iostream>
#include <vector>
#include <cassert>
#include <algorithm>
#include <cmath>
#include <random>
using namespace std;
using ll = long long;

struct poly2 {
    ll a, b, c;

    poly2() {}

    poly2(ll a_, ll b_, ll c_): a(a_), b(b_), c(c_) {}

    double atx(double x) {
        return a * x * x + b * x + c;
    }

    pair<double, double> aty(double y) {
        double D = b * b - 4 * a * (c - y);
        double x1 = (-b - sqrt(D)) / a / 2;
        double x2 = (-b + sqrt(D)) / a / 2;
        if (a < 0)
            swap(x1, x2);
        return {x1, x2};
    }

    poly2 operator+(const poly2 p) const {
        return {a + p.a, b + p.b, c + p.c};
    }

    poly2 operator-() const {
        return {-a, -b, -c};
    }

    poly2 operator-(const poly2 p) const {
        return {a - p.a, b - p.b, c - p.c};
    }


    bool in(double x, double y) {
        return (a > 0 && y >= atx(x)) || (a < 0 && y <= atx(x));
    }

    pair<double, double> intersect(poly2 p) {
        poly2 dif = *this - p;
        auto [x1, x2] = dif.aty(0);
        return {x1, x2};
    }
};

pair<double, double> highest(poly2 p1, poly2 p2) {
    if (p1.a > 0)
        swap(p1, p2);
    auto [x1, x2] = p1.intersect(p2);
    double x0 = 1.0 * p1.b / 2 / p1.a;
    if (x1 <= x0 && x0 <= x2) {
        return {x0, p1.atx(x0)};
    } else if (p1.atx(x1) <= p1.atx(x2)) {
        return {x2, p1.atx(x2)};
    } else {
        return {x1, p1.atx(x1)};
    }
}

const int MAXN = 1e5 + 123;
poly2 a[MAXN];

pair<double, double> intersect(pair<double, double> p1, pair<double, double> p2) {
    return {max(p1.first, p2.first), min(p1.second, p2.second)};
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    int n;
    cin >> n;
    bool ispos = false;
    bool isneg = false;
    vector<poly2> pos;
    vector<poly2> neg;
    for (int i = 0; i < n; ++i) {
        cin >> a[i].a >> a[i].b >> a[i].c;
    }
    double x = 0;
    double y = 1000000008;
    if (a[0].a < 0)
        y *= -1;
    for (int i = 0; i < n; ++i) {
        if (!a[i].in(x, y)) {
            pair<double, double> p = a[i].intersect(a[i - 1]);
            for (int j = 0; j < i - 1; ++j) {
                p = intersect(p, a[i].intersect(a[j]));
            }
            cout << i << endl;
            assert(p.first <= p.second);
            x = p.first;
            y = a[i].atx(x);
        }
    }
    for (int i = 0; i < n; ++i) {
        assert(a[i].in(x, y));
    }
    printf("%.20f %.20f\n", x, y);
}
